@@ -44,7 +44,8 @@ class simple_discord_bot(discord.Client):
         command_list.append(command_to_add)
 
     def set_token(self, token):
-        command_dict["discord_bot_token"] = token
+        client.run(token)
+
 
 @client.event
 async def on_ready():
@@ -223,7 +224,6 @@ async def on_message(message):
 
 
 try:
-    print("Attempting to login to Discord...")
-    client.run(f"{command_dict['discord_bot_token']}")
+print("Attempting to login to Discord...")
 except Exception as login_error:
     print(login_error)
